==> simple-react-data-grid-2.0.5.tgz: package/src/components/dataGrid/Search.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';

/*
* The Search component for the grid which will handle the onSearch and searchOptions functionality for the grid.
* @type {class}
*/

class Search extends Component {
  constructor(props) {
    super(props);
    this.state = {
      inputValue: '',
      selectedColumn: 'all',
    };
    this.handleInputChange = this.handleInputChange.bind(this);
    this.handleSelectChange = this.handleSelectChange.bind(this);
    this.onClickSearch = this.onClickSearch.bind(this);
  }

  handleInputChange(event) {
    this.setState({ inputValue: event.target.value });
  }
  handleSelectChange(event) {
    this.setState({
      selectedColumn: event.target.value,
    });
  }

  onClickSearch() {
    const searchInput = {
      searchEntity: this.state.inputValue,
      selectedColumn: this.state.selectedColumn,
    };
    this.props.onSearch(searchInput);
  }
  /* TODO
   "For sorting logic there is a replacement for another logic".
   */
  searchOptions() {
    const Options = ({ metaData }) => (
      <option value={metaData.key}>
        {metaData.name.charAt(0).toUpperCase()}{metaData.name.slice(1).toLowerCase()}
      </option>
    );
    return this.props.metaData.map(
      (optionMetaData) => {
        if (!optionMetaData) {
          return null;
        }
        if (!optionMetaData.disableFilter) {
          return (
            <Options
              metaData={optionMetaData}
              key={optionMetaData.name}
            />
          );
        }
      });
  }
  render() {
    return (
      <div className="search-bar" >
        <label>
          <input className="search-input" type="text" onChange={this.handleInputChange} />
        </label>
        <div
          className="search"
          onClick={this.onClickSearch}
        >
          <div className="search__circle" />
          <div className="search__rectangle" />
        </div>
        <select className="search-input-bar" onChange={this.handleSelectChange} value={this.state.selectedColumn}>
          <option value="all"> All</option>
          {this.searchOptions()}
        </select>
      </div>

    );
  }
}

Search.propTypes = {
  metaData: PropTypes.array,
  onSearch: PropTypes.func.isRequired,
};

Search.defaultProps = {
  metaData: {},
};

export default Search;

==> simple-react-data-grid-2.0.6.tgz: package/src/components/dataGrid/Search.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';

/*
* The Search component for the grid which will handle the onSearch and searchOptions functionality for the grid.
* @type {class}
*/

class Search extends Component {
  constructor(props) {
    super(props);
    this.state = {
      inputValue: '',
      selectedColumn: '',
    };
    this.handleInputChange = this.handleInputChange.bind(this);
    this.handleSelectChange = this.handleSelectChange.bind(this);
    this.onClickSearch = this.onClickSearch.bind(this);
  }

  handleInputChange(event) {
    this.setState({ inputValue: event.target.value });
  }
  handleSelectChange(event) {
    this.setState({
      selectedColumn: event.target.value,
    });
  }

  onClickSearch() {
    const searchInput = {
      searchEntity: this.state.inputValue,
      selectedColumn: this.state.selectedColumn,
    };
    this.props.onSearch(searchInput);
  }
  /* TODO
   "For sorting logic there is a replacement for another logic".
   */
  addAllOption() {
    if (this.props.metaData.includeGlobalFilter) {
      return (
        <option value="all" key="all"> All</option>
      );
    }
  }
  addOptions() {
    const Options = ({ metaData }) => (
      <option value={metaData.key}>
        {metaData.name.charAt(0).toUpperCase()}{metaData.name.slice(1).toLowerCase()}
      </option>
    );
    /* TODO
    "Need to fix this."
    * */
    return this.props.metaData.headerConfig.map(
      (optionMetaData) => {
        if (!optionMetaData) {
          return null;
        }
        if (!optionMetaData.disableFilter) {
          return (
            <Options
              metaData={optionMetaData}
              key={optionMetaData.name}
            />
          );
        }
        return null;
      });
  }
  render() {
    if (this.props.metaData.includeGlobalFilter) {
      return (
        <div className="search-bar">
          <label>
            <input className="search-input" type="text" onChange={this.handleInputChange} />
          </label>
          <div
            className="search"
            onClick={this.onClickSearch}
          >
            <div className="search__circle" />
            <div className="search__rectangle" />
          </div>
          <select className="search-input-bar" onChange={this.handleSelectChange} value={this.state.selectedColumn}>
            <option />
            {this.addAllOption()}
            {this.addOptions()}
          </select>
        </div>

      );
    }
    return null;
  }
}

Search.propTypes = {
  metaData: PropTypes.object,
  onSearch: PropTypes.func.isRequired,
};

Search.defaultProps = {
  metaData: {},
};

export default Search;
